aboutsummaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorpriscilla <priscilla.huang@efrei.net>2023-01-31 09:06:20 -0500
committerpriscilla <priscilla.huang@efrei.net>2023-01-31 09:06:41 -0500
commit3645e148dd673d0f5b72226a9d9a6310cbe21be0 (patch)
tree7287a1c15ff22d559852e596e52eb3943564c990 /src/include
parentbf872f712e7af196341a0aacde1c0fd70b046e72 (diff)
backend pending webhook
Diffstat (limited to 'src/include')
-rw-r--r--src/include/taler_merchantdb_plugin.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/src/include/taler_merchantdb_plugin.h b/src/include/taler_merchantdb_plugin.h
index d9fe0d24..fe974ba4 100644
--- a/src/include/taler_merchantdb_plugin.h
+++ b/src/include/taler_merchantdb_plugin.h
@@ -409,7 +409,7 @@ typedef void
* Typically called by `lookup_pending_webhooks`.
*
* @param cls a `json_t *` JSON array to build
* @param webhook_serial reference to the configured webhook template.
* @param next_attempt is the time we should make the next request to the webhook.
* @param retries how often have we tried this request to the webhook.
* @param url to make request to
@@ -419,9 +419,8 @@ typedef void
*/
typedef void
(*TALER_MERCHANTDB_PendingWebhooksCallback)(void *cls,
- uint64_t webhook_serial,
- struct GNUNET_TIME_Absolute
- next_attempt,
+ uint64_t webhook_pending_serial,
+ struct GNUNET_TIME_Absolute next_attempt,
uint32_t retries,
const char *url,
const char *http_method,
@@ -455,13 +454,11 @@ struct TALER_MERCHANTDB_PendingWebhookDetails
*/
char *http_method;
-
/**
* Header of the webhook.
*/
char *header;
-
/**
* Body of the webhook.
*/
@@ -2827,7 +2824,7 @@ struct TALER_MERCHANTDB_Plugin
*/
enum GNUNET_DB_QueryStatus
(*update_pending_webhook)(void *cls,
- uint64_t webhook_serial,
+ uint64_t webhook_pending_serial,
struct GNUNET_TIME_Absolute next_attempt);
// maybe add: http status of failure?
@@ -2842,7 +2839,7 @@ struct TALER_MERCHANTDB_Plugin
*/
enum GNUNET_DB_QueryStatus
(*delete_pending_webhook)(void *cls,
- uint64_t webhook_serial);
+ uint64_t webhook_pending_serial);
};
@@ -409,7 +409,7 @@ typedef void
*
* @param cls a `json_t *` JSON array to build
- * @param webhook_serial reference to the configured webhook template.
+ * @param webhook_pending_serial reference to the configured webhook template.
* @param next_attempt is the time we should make the next request to the webhook.
* @param retries how often have we tried this request to the webhook.